/*
 *  $Id: string-list.c 27631 2025-03-26 17:14:20Z yeti-dn $
 *  Copyright (C) 2009-2025 David Nečas (Yeti).
 *  E-mail: yeti@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
 *  later version.
 *
 *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "testlibgwy.h"

void
test_string_list_append(void)
{
    GwyStringList *strlist = gwy_string_list_new();

    g_assert_cmpuint(gwy_string_list_get_length(strlist), ==, 0);
    gwy_string_list_append(strlist, "First");
    g_assert_cmpuint(gwy_string_list_get_length(strlist), ==, 1);
    gwy_string_list_append_take(strlist, g_strdup("Second"));
    g_assert_cmpuint(gwy_string_list_get_length(strlist), ==, 2);

    g_assert_cmpstr(gwy_string_list_get(strlist, 0), ==, "First");
    g_assert_cmpstr(gwy_string_list_get(strlist, 1), ==, "Second");

    gwy_string_list_clear(strlist);
    g_assert_cmpuint(gwy_string_list_get_length(strlist), ==, 0);

    g_object_unref(strlist);
}

static void
string_list_assert_equal(GObject *object, GObject *reference)
{
    g_assert_true(GWY_IS_STRING_LIST(object));
    g_assert_true(GWY_IS_STRING_LIST(reference));

    GwyStringList *strlist = GWY_STRING_LIST(object), *strlist_ref = GWY_STRING_LIST(reference);
    g_assert_cmpuint(gwy_string_list_get_length(strlist), ==, gwy_string_list_get_length(strlist_ref));
    guint n = gwy_string_list_get_length(strlist_ref);
    for (guint i = 0; i < n; i++) {
        g_assert_cmpstr(gwy_string_list_get(strlist, i), ==, gwy_string_list_get(strlist_ref, i));
    }
}

void
test_string_list_assign(void)
{
    GwyStringList *strlist = gwy_string_list_new();
    gwy_string_list_append(strlist, "one");
    gwy_string_list_append(strlist, "two");
    gwy_string_list_append(strlist, "four");

    GwyStringList *another = gwy_string_list_new();
    gwy_string_list_append(another, "x");

    gwy_string_list_assign(another, strlist);
    string_list_assert_equal(G_OBJECT(another), G_OBJECT(strlist));

    g_object_unref(another);
    g_object_unref(strlist);
}

void
test_string_list_copy(void)
{
    GwyStringList *strlist = gwy_string_list_new();
    gwy_string_list_append(strlist, "one");
    gwy_string_list_append(strlist, "two");
    gwy_string_list_append(strlist, "four");

    GwyStringList *another = gwy_string_list_copy(strlist);
    string_list_assert_equal(G_OBJECT(another), G_OBJECT(strlist));

    g_object_unref(another);
    g_object_unref(strlist);
}

void
test_string_list_serialize_simple(void)
{
    GwyStringList *strlist = gwy_string_list_new();
    gwy_string_list_append(strlist, "AAAAAA");
    gwy_string_list_append(strlist, "B&B");
    gwy_string_list_append(strlist, "see");

    GObject *reconstructed = serialize_object_and_back(G_OBJECT(strlist), string_list_assert_equal, NULL);

    g_object_unref(reconstructed);
    g_object_unref(strlist);
}

/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
