/*
 *  $Id: gwydgetutils.h 27391 2025-02-28 13:26:20Z yeti-dn $
 *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
 *  later version.
 *
 *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __GWY_GWYDGET_UTILS_H__
#define __GWY_GWYDGET_UTILS_H__

#include <math.h>
#include <gtk/gtk.h>
#include <libgwydgets/color-button.h>

G_BEGIN_DECLS

#define gwy_adjustment_get_int(adj) ((gint)floor(gtk_adjustment_get_value(GTK_ADJUSTMENT(adj)) + 0.5))

/* TODO GTK3 remove the entire hscale set of functions after we use something better in Gwy3DWindow. The only
 * other users are calcoefs_view (which will be removed) and roddeposit_synth.c (which Petr has to port to
 * ParamTable). */
typedef enum {
    GWY_HSCALE_DEFAULT          = 0,
    GWY_HSCALE_LOG              = 1,
    GWY_HSCALE_SQRT             = 2,
    GWY_HSCALE_LINEAR           = 3,
    GWY_HSCALE_NO_SCALE         = 6,
    GWY_HSCALE_WIDGET           = 7,
    GWY_HSCALE_WIDGET_NO_EXPAND = 8,
    GWY_HSCALE_CHECK            = 1024,
    GWY_HSCALE_SNAP             = 2048,
} GwyHScaleStyle;

GtkWidget* gwy_gtkgrid_attach_adjbar           (GtkGrid *grid,
                                                gint row,
                                                const gchar *name,
                                                const gchar *units,
                                                GObject *pivot,
                                                GwyHScaleStyle style);
void       gwy_gtkgrid_hscale_set_sensitive    (GObject *pivot,
                                                gboolean sensitive);
GtkWidget* gwy_gtkgrid_hscale_get_scale        (GObject *pivot);
GtkWidget* gwy_gtkgrid_hscale_get_check        (GObject *pivot);
GtkWidget* gwy_gtkgrid_hscale_get_label        (GObject *pivot);
GtkWidget* gwy_gtkgrid_hscale_get_units        (GObject *pivot);
GtkWidget* gwy_gtkgrid_hscale_get_middle_widget(GObject *pivot);
void       gwy_color_selector_for_mask         (const gchar *dialog_title,
                                                GwyColorButton *color_button,
                                                GwyContainer *container,
                                                const gchar *prefix);
void       gwy_mask_color_selector_run         (const gchar *dialog_title,
                                                GtkWindow *parent,
                                                GwyColorButton *color_button,
                                                GwyContainer *container,
                                                const gchar *prefix);
void       gwy_list_store_row_changed          (GtkListStore *store,
                                                GtkTreeIter *iter,
                                                GtkTreePath *path,
                                                gint row);
GtkWidget* gwy_label_new_header                (const gchar *text);
GtkWidget* gwy_stock_like_button_new           (const gchar *label_text,
                                                const gchar *icon_name);
GtkWidget* gwy_tool_like_button_new            (const gchar *label_text,
                                                const gchar *icon_name);
gboolean   gwy_widget_get_activate_on_unfocus  (GtkWidget *widget);
void       gwy_widget_set_activate_on_unfocus  (GtkWidget *widget,
                                                gboolean activate);
void       gwy_widget_sync_sensitivity         (GtkWidget *master,
                                                GtkWidget *slave);
gboolean   gwy_widget_is_hbox                  (GtkWidget *widget);
GtkWidget* gwy_add_button_to_dialog            (GtkDialog *dialog,
                                                const gchar *label_text,
                                                const gchar *icon_name,
                                                gint response_id);
void       gwy_set_message_label               (GtkLabel *label,
                                                const gchar *text,
                                                GtkMessageType type,
                                                gboolean is_markup);

G_END_DECLS

#endif /* __GWY_GWYDGET_UTILS_H__ */

/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
