/*
 *  $Id: gwyruler.h 27391 2025-02-28 13:26:20Z yeti-dn $
 *  Copyright (C) 2003-2024 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
 *  later version.
 *
 *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __GWY_RULER_H__
#define __GWY_RULER_H__

#include <gdk/gdk.h>
#include <gtk/gtk.h>

#include <libgwyddion/gwysiunit.h>

G_BEGIN_DECLS

typedef enum {
    GWY_UNITS_PLACEMENT_NONE,
    GWY_UNITS_PLACEMENT_AT_ZERO
} GwyUnitsPlacement;

#define GWY_TYPE_RULER            (gwy_ruler_get_type())
#define GWY_RULER(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GWY_TYPE_RULER, GwyRuler))
#define GWY_RULER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), GWY_TYPE_RULER, GwyRulerClass))
#define GWY_IS_RULER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GWY_TYPE_RULER))
#define GWY_IS_RULER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), GWY_TYPE_RULER))
#define GWY_RULER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GWY_TYPE_RULER, GwyRulerClass))

typedef struct _GwyRuler             GwyRuler;
typedef struct _GwyRulerClass        GwyRulerClass;
typedef struct _GwyRulerPrivate      GwyRulerPrivate;
typedef struct _GwyRulerClassPrivate GwyRulerClassPrivate;

struct _GwyRuler {
    GtkWidget widget;
    GwyRulerPrivate *priv;

    /* FIXME we access these from subclasses, but they should be protected, not public (or even better get rid of
     * subclasses and add an Orientation property). */
    PangoLayout *layout;
    /* FIXME height is more like thickness (i.e. the non-length dimension). */
    gint hthickness, vthickness, height, pixelsize;

    gdouble lower;    /* The upper limit of the ruler (in physical units) */
    gdouble upper;    /* The lower limit of the ruler */
    gdouble position;    /* The position of the mark on the ruler */

};

struct _GwyRulerClass {
    GtkWidgetClass parent_class;
    GwyRulerClassPrivate *priv;

    /* Virtual methods */
    void (*prepare_sizes)(GwyRuler *ruler);
    void (*draw_layout)  (GwyRuler *ruler,
                          cairo_t *cr,
                          gint hpos,
                          gint vpos);
    void (*draw_tick)    (GwyRuler *ruler,
                          cairo_t *cr,
                          gdouble pos,
                          gdouble length);
    void (*draw_pos)     (GwyRuler *ruler,
                          cairo_t *cr);
    void (*queue_marker_redraw) (GwyRuler *ruler,
                                 gdouble value);

    void (*reserved1)(void);
    void (*reserved2)(void);
};


GType             gwy_ruler_get_type            (void)                         G_GNUC_CONST;
void              gwy_ruler_set_range           (GwyRuler *ruler,
                                                 gdouble lower,
                                                 gdouble upper,
                                                 gdouble position,
                                                 gdouble max_size);
void              gwy_ruler_get_range           (GwyRuler *ruler,
                                                 gdouble *lower,
                                                 gdouble *upper,
                                                 gdouble *position,
                                                 gdouble *max_size);
void              gwy_ruler_set_si_unit         (GwyRuler *ruler,
                                                 GwySIUnit *units);
GwySIUnit*        gwy_ruler_get_si_unit         (GwyRuler *ruler);
GwyUnitsPlacement gwy_ruler_get_units_placement (GwyRuler *ruler);
void              gwy_ruler_set_units_placement (GwyRuler *ruler,
                                                 GwyUnitsPlacement placement);
void              gwy_ruler_move_marker         (GwyRuler *ruler,
                                                 gdouble value);
gdouble           gwy_ruler_coord_real_to_widget(GwyRuler *ruler,
                                                 gdouble value);
gdouble           gwy_ruler_coord_widget_to_real(GwyRuler *ruler,
                                                 gdouble pos);


G_END_DECLS

#endif /* __GWY_RULER_H__ */

/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
