/*
 *  $Id: grains.h 27421 2025-03-03 23:13:22Z yeti-dn $
 *  Copyright (C) 2003-2022 David Necas (Yeti), Petr Klapetek.
 *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
 *
 *  This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any
 *  later version.
 *
 *  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along with this program; if not, write to the
 *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __GWY_PROCESS_GRAINS_H__
#define __GWY_PROCESS_GRAINS_H__

#include <libprocess/datafield.h>
#include <libprocess/gwyprocesstypes.h>

G_BEGIN_DECLS

/* The values should not grow over 62 (to be usable as bit positions) */
typedef enum {
    GWY_GRAIN_VALUE_PROJECTED_AREA          = 0,
    GWY_GRAIN_VALUE_EQUIV_SQUARE_SIDE       = 1,
    GWY_GRAIN_VALUE_EQUIV_DISC_RADIUS       = 2,
    GWY_GRAIN_VALUE_SURFACE_AREA            = 3,
    GWY_GRAIN_VALUE_MAXIMUM                 = 4,
    GWY_GRAIN_VALUE_MINIMUM                 = 5,
    GWY_GRAIN_VALUE_MEAN                    = 6,
    GWY_GRAIN_VALUE_MEDIAN                  = 7,
    GWY_GRAIN_VALUE_PIXEL_AREA              = 8,
    GWY_GRAIN_VALUE_HALF_HEIGHT_AREA        = 9,
    GWY_GRAIN_VALUE_FLAT_BOUNDARY_LENGTH    = 10,
    GWY_GRAIN_VALUE_RMS                     = 11,
    GWY_GRAIN_VALUE_MINIMUM_BOUND_SIZE      = 12,
    GWY_GRAIN_VALUE_MINIMUM_BOUND_ANGLE     = 13,
    GWY_GRAIN_VALUE_MAXIMUM_BOUND_SIZE      = 14,
    GWY_GRAIN_VALUE_MAXIMUM_BOUND_ANGLE     = 15,
    GWY_GRAIN_VALUE_CENTER_X                = 16,
    GWY_GRAIN_VALUE_CENTER_Y                = 17,
    GWY_GRAIN_VALUE_VOLUME_0                = 18,
    GWY_GRAIN_VALUE_VOLUME_MIN              = 19,
    GWY_GRAIN_VALUE_VOLUME_LAPLACE          = 20,
    /* Free space 21-22 */
    GWY_GRAIN_VALUE_SLOPE_THETA             = 23,
    GWY_GRAIN_VALUE_SLOPE_PHI               = 24,
    GWY_GRAIN_VALUE_BOUNDARY_MAXIMUM        = 25,
    GWY_GRAIN_VALUE_BOUNDARY_MINIMUM        = 26,
    GWY_GRAIN_VALUE_CURVATURE_CENTER_X      = 27,
    GWY_GRAIN_VALUE_CURVATURE_CENTER_Y      = 28,
    GWY_GRAIN_VALUE_CURVATURE_CENTER_Z      = 29,
    GWY_GRAIN_VALUE_CURVATURE1              = 30,
    GWY_GRAIN_VALUE_CURVATURE2              = 31,
    GWY_GRAIN_VALUE_CURVATURE_ANGLE1        = 32,
    GWY_GRAIN_VALUE_CURVATURE_ANGLE2        = 33,
    GWY_GRAIN_VALUE_INSCRIBED_DISC_R        = 34,
    GWY_GRAIN_VALUE_INSCRIBED_DISC_X        = 35,
    GWY_GRAIN_VALUE_INSCRIBED_DISC_Y        = 36,
    GWY_GRAIN_VALUE_CONVEX_HULL_AREA        = 37,
    GWY_GRAIN_VALUE_CIRCUMCIRCLE_R          = 38,
    GWY_GRAIN_VALUE_CIRCUMCIRCLE_X          = 39,
    GWY_GRAIN_VALUE_CIRCUMCIRCLE_Y          = 40,
    GWY_GRAIN_VALUE_MEAN_RADIUS             = 41,
    GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MAJOR     = 42,
    GWY_GRAIN_VALUE_EQUIV_ELLIPSE_MINOR     = 43,
    GWY_GRAIN_VALUE_EQUIV_ELLIPSE_ANGLE     = 44,
    GWY_GRAIN_VALUE_MINIMUM_MARTIN_DIAMETER = 45,
    GWY_GRAIN_VALUE_MINIMUM_MARTIN_ANGLE    = 46,
    GWY_GRAIN_VALUE_MAXIMUM_MARTIN_DIAMETER = 47,
    GWY_GRAIN_VALUE_MAXIMUM_MARTIN_ANGLE    = 48,
} GwyGrainQuantity;

typedef enum {
    GWY_DISTANCE_TRANSFORM_CITYBLOCK   = 0,
    GWY_DISTANCE_TRANSFORM_CONN4       = 0,
    GWY_DISTANCE_TRANSFORM_CHESS       = 1,
    GWY_DISTANCE_TRANSFORM_CONN8       = 1,
    GWY_DISTANCE_TRANSFORM_OCTAGONAL48 = 2,
    GWY_DISTANCE_TRANSFORM_OCTAGONAL84 = 3,
    GWY_DISTANCE_TRANSFORM_OCTAGONAL   = 4,
    GWY_DISTANCE_TRANSFORM_EUCLIDEAN   = 5,
} GwyDistanceTransformType;

const GwyEnum*       gwy_distance_transform_type_get_enum            (void)                               G_GNUC_CONST;
void                 gwy_data_field_grains_mark_curvature            (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gdouble threshval,
                                                                      gboolean below);
void                 gwy_data_field_grains_mark_watershed            (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gint locate_steps,
                                                                      gint locate_thresh,
                                                                      gdouble locate_dropsize,
                                                                      gint wshed_steps,
                                                                      gdouble wshed_dropsize,
                                                                      gboolean prefilter,
                                                                      gboolean below);
gboolean             gwy_data_field_grains_remove_grain              (GwyDataField *grain_field,
                                                                      gint col,
                                                                      gint row);
gboolean             gwy_data_field_grains_extract_grain             (GwyDataField *grain_field,
                                                                      gint col,
                                                                      gint row);
void                 gwy_data_field_grains_remove_by_number          (GwyDataField *grain_field,
                                                                      gint number);
void                 gwy_data_field_grains_remove_by_size            (GwyDataField *grain_field,
                                                                      gint size);
void                 gwy_data_field_grains_remove_by_height          (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gdouble threshval,
                                                                      gboolean below);
void                 gwy_data_field_grains_remove_touching_border    (GwyDataField *grain_field);
GwyComputationState* gwy_data_field_grains_watershed_init            (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gint locate_steps,
                                                                      gint locate_thresh,
                                                                      gdouble locate_dropsize,
                                                                      gint wshed_steps,
                                                                      gdouble wshed_dropsize,
                                                                      gboolean prefilter,
                                                                      gboolean below);
void                 gwy_data_field_grains_watershed_iteration       (GwyComputationState *state);
void                 gwy_data_field_grains_watershed_finalize        (GwyComputationState *state);
void                 gwy_data_field_grains_mark_height               (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gdouble threshval,
                                                                      gboolean below);
void                 gwy_data_field_grains_mark_slope                (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      gdouble threshval,
                                                                      gboolean below);
gdouble              gwy_data_field_otsu_threshold                   (GwyDataField *data_field);
void                 gwy_data_field_grains_add                       (GwyDataField *grain_field,
                                                                      GwyDataField *add_field);
void                 gwy_data_field_grains_intersect                 (GwyDataField *grain_field,
                                                                      GwyDataField *intersect_field);
void                 gwy_data_field_grains_invert                    (GwyDataField *grain_field);
gboolean             gwy_data_field_grains_autocrop                  (GwyDataField *mask_field,
                                                                      gboolean symmetrically,
                                                                      guint *left,
                                                                      guint *right,
                                                                      guint *up,
                                                                      guint *down);
gint                 gwy_data_field_number_grains                    (GwyDataField *mask_field,
                                                                      gint *grains);
gint                 gwy_data_field_number_grains_periodic           (GwyDataField *mask_field,
                                                                      gint *grains);
gint*                gwy_data_field_get_grain_bounding_boxes         (GwyDataField *mask_field,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      gint *bboxes);
gint*                gwy_data_field_get_grain_bounding_boxes_periodic(GwyDataField *mask_field,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      gint *bboxes);
gint*                gwy_data_field_get_grain_sizes                  (GwyDataField *mask_field,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      gint *sizes);
gint*                gwy_data_field_get_grain_inscribed_boxes        (GwyDataField *mask_field,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      gint *iboxes);
gint*                gwy_data_field_grains_find_boundaries           (GwyDataField *data_field,
                                                                      const gint *grains,
                                                                      gint ngrains,
                                                                      gint *bindex,
                                                                      gboolean from_border);
GwyDataLine*         gwy_data_field_grains_get_distribution          (GwyDataField *data_field,
                                                                      GwyDataField *grain_field,
                                                                      GwyDataLine *distribution,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      GwyGrainQuantity quantity,
                                                                      gint nstats);
gdouble*             gwy_data_field_grains_get_values                (GwyDataField *data_field,
                                                                      gdouble *values,
                                                                      gint ngrains,
                                                                      const gint *grains,
                                                                      GwyGrainQuantity quantity);
gdouble**            gwy_data_field_grains_get_quantities            (GwyDataField *data_field,
                                                                      gdouble **values,
                                                                      const GwyGrainQuantity *quantities,
                                                                      guint nquantities,
                                                                      guint ngrains,
                                                                      const gint *grains);
gboolean             gwy_grain_quantity_needs_same_units             (GwyGrainQuantity quantity);
GwySIUnit*           gwy_grain_quantity_get_units                    (GwyGrainQuantity quantity,
                                                                      GwySIUnit *siunitxy,
                                                                      GwySIUnit *siunitz,
                                                                      GwySIUnit *result);
void                 gwy_data_field_area_grains_tgnd                 (GwyDataField *data_field,
                                                                      GwyDataLine *target_line,
                                                                      gint col,
                                                                      gint row,
                                                                      gint width,
                                                                      gint height,
                                                                      gboolean below,
                                                                      gint nstats);
void                 gwy_data_field_area_grains_tgnd_range           (GwyDataField *data_field,
                                                                      GwyDataLine *target_line,
                                                                      gint col,
                                                                      gint row,
                                                                      gint width,
                                                                      gint height,
                                                                      gdouble min,
                                                                      gdouble max,
                                                                      gboolean below,
                                                                      gint nstats);
void                 gwy_data_field_grains_splash_water              (GwyDataField *data_field,
                                                                      GwyDataField *minima,
                                                                      gint locate_steps,
                                                                      gdouble locate_dropsize);
void                 gwy_data_field_grain_distance_transform         (GwyDataField *data_field);
void                 gwy_data_field_grain_simple_dist_trans          (GwyDataField *data_field,
                                                                      GwyDistanceTransformType dtype,
                                                                      gboolean from_border);
void                 gwy_data_field_grains_shrink                    (GwyDataField *data_field,
                                                                      gdouble amount,
                                                                      GwyDistanceTransformType dtype,
                                                                      gboolean from_border);
void                 gwy_data_field_grains_grow                      (GwyDataField *data_field,
                                                                      gdouble amount,
                                                                      GwyDistanceTransformType dtype,
                                                                      gboolean prevent_merging);
void                 gwy_data_field_grains_thin                      (GwyDataField *data_field);
gboolean             gwy_data_field_fill_voids                       (GwyDataField *data_field,
                                                                      gboolean nonsimple);
gint                 gwy_data_field_waterpour                        (GwyDataField *data_field,
                                                                      GwyDataField *result,
                                                                      gint *grains);
void                 gwy_data_field_mark_extrema                     (GwyDataField *dfield,
                                                                      GwyDataField *extrema,
                                                                      gboolean maxima);

G_END_DECLS

#endif /* __GWY_PROCESS_GRAINS__ */

/* vim: set cin columns=120 tw=118 et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
