#!/usr/bin/python
# FIXME: Support srcdir ≠ builddir.
import sys, os, re

exit_status = 0

def error(s):
    global exit_status
    sys.stderr.write(s + '\n')
    exit_status = 1

scriptname = sys.argv[1]
script = ['export-type:png', 'export-area-page']
dirs_to_make = set()

icon_re = re.compile(r'^(?P<size>\d+)x(?P=size)/(?P<type>[a-zA-Z-]+)/(?P<name>.*?)\.png$')

for outfile in sys.argv[2:]:
    m = icon_re.search(outfile)
    if not m:
        error('Failed to parse output filename %s.' % outfile)
        continue

    size, name = m.group('size'), m.group('name')
    srcfile = 'src/%s-%s.svg' % (name, size)
    try:
        mtime_src = os.stat(srcfile).st_mtime
    except FileNotFoundError:
        error('Input filename %s for %s does not exist' % (srcfile, outfile))
        continue

    try:
        mtime_out = os.stat(outfile).st_mtime
    except FileNotFoundError:
        mtime_out = -1

    if mtime_out >= mtime_src:
        #sys.stderr.write('File %s is up to date.\n' % outfile)
        continue

    script.append('file-open:%s' % srcfile)
    script.append('export-width:%s' % size)
    script.append('export-height:%s' % size)
    script.append('export-filename:%s' % outfile)
    script.append('export-do')
    script.append('file-close')

    dirs_to_make.add(os.path.dirname(outfile))

script.append('quit')

if len(script) > 6:
    with open(scriptname, 'w') as fh:
        fh.write('\n'.join(script) + '\n')

    for d in dirs_to_make:
        if d != '.':
            os.makedirs(d, exist_ok=True)
else:
    try:
        os.unlink(scriptname)
    except FileNotFoundError:
        pass

sys.exit(exit_status)
